;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ialign" "20251020.2046"
  "Interactive align-regexp."
  '((emacs "25.1"))
  :url "https://github.com/mkcms/interactive-align"
  :commit "6ed18b077af4946233c140a63465ea1b54654ede"
  :revdesc "6ed18b077af4"
  :keywords '("tools" "editing" "align" "interactive")
  :authors '(("Michał Krzywkowski" . "k.michal@zoho.com"))
  :maintainers '(("Michał Krzywkowski" . "k.michal@zoho.com")))
